<?php
namespace PortalPeople\DisabledDates\Model;

use Magento\Framework\Model\AbstractModel;

class DisabledDate extends AbstractModel
{
    protected function _construct()
    {
        $this->_init(\PortalPeople\DisabledDates\Model\ResourceModel\DisabledDate::class);
    }
}
