<?php
namespace PortalPeople\DisabledDates\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

class DisabledDate extends AbstractDb
{
    protected function _construct()
    {
        try {
            $this->_init('portal_people_disabled_dates', 'entity_id');
        } catch (\Exception $e) {
            $this->_logger->critical('DisabledDate ResourceModel initialization failed: ' . $e->getMessage());
            throw $e;
        }
    }
}
