<?php

namespace PortalPeople\DisabledDates\Block\Adminhtml\Grid;

use Magento\Backend\Block\Widget\Grid\Container as GridContainer;

class Container extends GridContainer
{
    protected function _construct()
    {
        $this->_controller = 'adminhtml_index';
        $this->_blockGroup = 'PortalPeople_DisabledDates';
        $this->_headerText = __('Disabled Dates');
        $this->_addButtonLabel = __('Add New Disabled Date');
        parent::_construct();
    }
}
